package jwt

import (
	"github.com/golang-jwt/jwt/v5"
	"github.com/stretchr/testify/assert"
	"path/filepath"
	"testing"
	"time"
)

type AccessTokenClaims struct {
	UserId    string `json:"id"`
	FirstName string `json:"fn"`
	LastName  string `json:"ln"`
	JWT
}

func TestJWT(t *testing.T) {
	dir := "./data/"

	accessClaims := AccessTokenClaims{
		UserId:    "123",
		FirstName: "Igor",
		LastName:  "Sypachev",
	}
	accessClaims.
		WithId("sadfswdf").
		WithTtl(20 * time.Minute).
		WithSessionId("wergwergw")

	privateKey, _ := ReadPrivateKey(filepath.Join(filepath.Dir(dir), "private"))
	token, err := Encode(accessClaims, privateKey)
	assert.Equal(t, true, err == nil)

	publicKey, _ := ReadPublicKey(filepath.Join(filepath.Dir(dir), "public"))
	decodedClaims, _ := Decode(token, &AccessTokenClaims{}, publicKey)
	f, _ := decodedClaims.(*AccessTokenClaims)
	assert.Equal(t, f.UserId, "123")
	assert.Equal(t, f.FirstName, "Igor")
	assert.Equal(t, f.LastName, "Sypachev")
}

func TestReNewJWT(t *testing.T) {
	accessClaims := AccessTokenClaims{
		UserId:    "123",
		FirstName: "Igor",
		LastName:  "Sypachev",
	}
	accessClaims.ExpiresAt = jwt.NewNumericDate(time.Now())
	accessClaims.IssuedAt = jwt.NewNumericDate(time.Now().Add(-1 * time.Hour))
	accessClaims.NotBefore = jwt.NewNumericDate(time.Now())

	assert.Equal(t, true, accessClaims.ExpiresAt.Time.Unix() <= time.Now().Unix())

	newAccessClaims, err := ReNew(accessClaims)
	assert.Equal(t, true, err == nil)

	assert.Equal(t, true, newAccessClaims.ExpiresAt.Time.Unix() > accessClaims.ExpiresAt.Time.Unix())
}
